---
title: <span class="badge object-type-scalar"></span> Tebibytes
---
# <span class="badge object-type-scalar"></span> Tebibytes

Data: tebibytes

## Definition

```python
# Data: tebibytes
Tebibytes: typing.Literal["tbytes"] = "tbytes"
```
